package org.rcisoft.bus.ossinfo.controller;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.bus.ossinfo.entity.OssInfo;
import org.rcisoft.bus.ossinfo.service.OssinfoService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("/ossinfo")
public class OssInfoController extends CyPaginationController<OssInfo> {
    @Autowired
    private OssinfoService ossInfoServiceImpl;

    @CyOpeLogAnno(title = "system-OssInfo管理-新增OssInfo", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加OssInfo", notes = "添加OssInfo")
    @PostMapping(value = "/add")
    public CyResult add(@Valid OssInfo ossInfo, BindingResult bindingResult) {
        CyPersistModel data = ossInfoServiceImpl.persist(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfo);
    }

    @CyOpeLogAnno(title = "system-OssInfo管理-删除OssInfo", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除OssInfo", notes="删除OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, OssInfo ossInfo) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.remove(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }
    @CyOpeLogAnno(title = "system-OssInfo管理-修改OssInfo", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改OssInfo", notes="修改OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid OssInfo ossInfo, BindingResult bindingResult) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.merge(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfo);
    }
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一OssInfo", notes="查询单一OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.findById(businessId));
    }

    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询OssInfo集合", notes="查询OssInfo集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(OssInfo ossInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.findAll(ossInfo));
    }
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询OssInfo集合", notes="分页查询OssInfo集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(OssInfo ossInfo) {
        ossInfoServiceImpl.findAllByPagination(getPaginationUtility(), ossInfo);
        return getGridModelResponse();
    }
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出OssInfo信息", notes = "导出OssInfo信息")
    @GetMapping(value = "/export")
    public void outOssInfo(HttpServletResponse response, OssInfo ossInfo, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="OssInfo信息.xls";break;
            case "1": excelName="OssInfo信息.xlsx";break;
            case "2": excelName="OssInfo信息.csv";break;
        }
        List<OssInfo> ossInfoList = ossInfoServiceImpl.export(ossInfo);
        CyEpExcelUtil.exportExcel(ossInfoList, "OssInfo信息", "OssInfo信息", OssInfo.class, excelName, response);
    }
}
